'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.prepareClassName = prepareClassName;
exports.isClassName = isClassName;
exports.getEntitiesFromBEMJSON = getEntitiesFromBEMJSON;

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _lodash = require('lodash.isplainobject');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createEntitiesAggregator(entities) {
    return function (bemjson) {
        if ((0, _lodash2.default)(bemjson)) {
            if ('block' in bemjson) {
                (function () {
                    if (typeof bemjson.block !== 'string') {
                        throw Error('block in ' + bemjson + ' should be a string');
                    }

                    var basicEntity = {
                        block: bemjson.block
                    };

                    if ('elem' in bemjson) {
                        if (typeof bemjson.elem !== 'string') {
                            throw Error('elem in ' + bemjson + ' should be a string');
                        }

                        basicEntity.elem = bemjson.elem;

                        entities.elems.push({
                            block: bemjson.block,
                            elem: bemjson.elem
                        });
                    } else {
                        entities.blocks.push(bemjson.block);
                    }

                    // mods
                    if ('mods' in bemjson) {
                        if (!(0, _lodash2.default)(bemjson.mods)) {
                            throw Error('mods in ' + bemjson + ' should be a plain object');
                        }

                        (0, _keys2.default)(bemjson.mods).forEach(function (modName) {
                            entities.mods.push((0, _extends3.default)({}, basicEntity, {
                                modName: modName,
                                modVal: bemjson.mods[modName]
                            }));
                        });
                    }
                })();
            } else {
                throw Error('there are no valid BEM entities in ' + bemjson);
            }
        } else {
            throw Error('expected ' + bemjson + ' to be a plain BEMJSON object');
        }
    };
}

function prepareClassName(element) {
    var className = isClassName(element) ? element : element.className;

    return className.trim().split(/\s+/);
}

function isClassName(element) {
    return typeof element === 'string';
}

function getEntitiesFromBEMJSON(bemjson) {
    var entities = {
        blocks: [],
        elems: [],
        mods: []
    };
    var fillEntitiesFrom = createEntitiesAggregator(entities);

    fillEntitiesFrom(bemjson);

    if ('mix' in bemjson) {
        if (Array.isArray(bemjson.mix)) {
            bemjson.mix.forEach(fillEntitiesFrom);
        } else {
            fillEntitiesFrom(bemjson.mix);
        }
    }

    return entities;
}